summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-07-09 19:38:30 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-07-10 20:56:11 -0500
commit49284edeff12e08d485e2546411f50142160bf3e (patch)
tree9558860cf12d5b6f305f211a4b22e029a5cc3d6e
parente4b75638052fd0a850014dece4b0c27e0349a027 (diff)
downloadlibpng-1.4.12-signed.tar.gz
[libpng14] Imported from libpng-1.4.12.tarv1.4.12libpng-1.4.12-signed
-rw-r--r--ANNOUNCE25
-rw-r--r--CHANGES6
-rw-r--r--CMakeLists.txt2
-rw-r--r--INSTALL4
-rw-r--r--LICENSE4
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.in4
-rw-r--r--README12
-rwxr-xr-xconfigure22
-rw-r--r--configure.ac4
-rw-r--r--contrib/pngsuite/README13
-rw-r--r--contrib/pngsuite/ftbbn0g01.pngbin0 -> 176 bytes
-rw-r--r--contrib/pngsuite/ftbbn0g02.pngbin0 -> 197 bytes
-rw-r--r--contrib/pngsuite/ftbbn0g04.png (renamed from contrib/pngsuite/ftbbn1g04.png)bin429 -> 429 bytes
-rw-r--r--contrib/pngsuite/ftbwn0g16.png (renamed from contrib/pngsuite/ftbwn1g16.png)bin1313 -> 1313 bytes
-rw-r--r--contrib/pngsuite/ftp0n0g08.png (renamed from contrib/pngsuite/ftp0n1g08.png)bin719 -> 719 bytes
-rw-r--r--libpng-1.4.12.txt (renamed from libpng-1.4.12beta01.txt)10
-rw-r--r--libpng.322
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h22
-rw-r--r--pngconf.h2
-rw-r--r--pngpriv.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt12
-rwxr-xr-xscripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/png32ce.def2
-rw-r--r--scripts/pngos2.def2
-rw-r--r--scripts/pngwin.def2
36 files changed, 105 insertions, 97 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 72934072b..6b667d903 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,32 +1,33 @@
-Libpng 1.4.12beta01 - April 26, 2012
+Libpng 1.4.12 - July 10, 2012
-This is not intended to be a public release. It will be replaced
-within a few weeks by a public version or by another test version.
+This is a public release of libpng, intended for use in production codes.
Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.4.12beta01.tar.xz (LZMA-compressed, recommended)
- 1.4.12beta01.tar.gz
- 1.4.12beta01.tar.bz2
+ libpng-1.4.12.tar.xz (LZMA-compressed, recommended)
+ libpng-1.4.12.tar.gz
+ libpng-1.4.12.tar.bz2
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1412b01.7z (LZMA-compressed, recommended)
- lp1412b01.zip
+ lpng1412.7z (LZMA-compressed, recommended)
+ lpng1412.zip
Other information:
- 1.4.12beta01-README.txt
- 1.4.12beta01-LICENSE.txt
+ libpng-1.4.12-README.txt
+ libpng-1.4.12-LICENSE.txt
Changes since the last public release (1.4.11):
-
-version 1.4.12 [April 26, 2012]
+ Added two images to contrib/pngsuite (1-bit and 2-bit transparent grayscale),
+ and renamed three whose names were inconsistent with those in
+ pngsuite/README.txt.
+ Changed "a+w" to "u+w" in Makefile.in to fix CVE-2012-3386.
Send comments/corrections/commendations to glennrp at users.sourceforge.net
or to png-mng-implement at lists.sf.net (subscription required; visit
diff --git a/CHANGES b/CHANGES
index 08518b968..7684a0809 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2868,7 +2868,11 @@ version 1.4.11 [March 29, 2012]
CVE-2011-3048).
Prevent PNG_EXPAND+PNG_SHIFT doing the shift twice.
-version 1.4.12 [April 26, 2012]
+version 1.4.12 [July 10, 2012]
+ Added two images to contrib/pngsuite (1-bit and 2-bit transparent grayscale),
+ and renamed three whose names were inconsistent with those in
+ pngsuite/README.txt.
+ Changed "a+w" to "u+w" in Makefile.in to fix CVE-2012-3386.
Send comments/corrections/commendations to glennrp at users.sourceforge.net
or to png-mng-implement at lists.sf.net (subscription required; visit
diff --git a/CMakeLists.txt b/CMakeLists.txt
index d3e7e6ab4..93380576e 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -255,7 +255,7 @@ install(CODE ${PNG_CONFIG_INSTALL_CODE})
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 14.${PNGLIB_RELEASE}.1.4.12beta01
+# VERSION 14.${PNGLIB_RELEASE}.1.4.12
VERSION 14.${PNGLIB_RELEASE}.0
SOVERSION 14
CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 6d4a508a5..cbdc2f55d 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.4.12beta01 - April 26, 2012
+Installing libpng version 1.4.12 - July 10, 2012
On Unix/Linux and similar systems, you can simply type
@@ -46,7 +46,7 @@ to have access to the zlib.h and zconf.h include files that
correspond to the version of zlib that's installed.
You can rename the directories that you downloaded (they
-might be called "libpng-1.4.12beta01" or "libpng14" and "zlib-1.2.3"
+might be called "libpng-1.4.12" or "libpng14" and "zlib-1.2.3"
or "zlib123") so that you have directories called "zlib" and "libpng".
Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index 1cb07b89e..fab92a4ea 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.12beta01, April 26, 2012, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.12, July 10, 2012, are
Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 26, 2012
+July 10, 2012
diff --git a/Makefile.am b/Makefile.am
index 75c6ede5d..300f9e2f8 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -79,7 +79,7 @@ EXTRA_DIST= \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.12beta01.txt
+ example.c libpng-1.4.12.txt
CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
diff --git a/Makefile.in b/Makefile.in
index 1ff6035d6..1518831ec 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -332,7 +332,7 @@ EXTRA_DIST = \
${srcdir}/contrib/pngsuite/* \
${srcdir}/contrib/visupng/* \
$(TESTS) \
- example.c libpng-1.4.12beta01.txt
+ example.c libpng-1.4.12.txt
CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
libpng.sym
@@ -1003,7 +1003,7 @@ distcheck: dist
*.zip*) \
unzip $(distdir).zip ;;\
esac
- chmod -R a-w $(distdir); chmod a+w $(distdir)
+ chmod -R a-w $(distdir); chmod u+w $(distdir)
mkdir $(distdir)/_build
mkdir $(distdir)/_inst
chmod a-w $(distdir)
diff --git a/README b/README
index addb57404..d1f36768c 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.12beta01 - April 26, 2012 (shared library 14.0)
+README for libpng version 1.4.12 - July 10, 2012 (shared library 14.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -182,9 +182,9 @@ Files in this distribution:
makefile.std => Generic UNIX makefile (cc, creates static
libpng.a)
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -206,12 +206,12 @@ Files in this distribution:
makefile.openbsd => OpenBSD makefile
makefile.sgi => Silicon Graphics IRIX (cc, creates static lib)
makefile.sggcc => Silicon Graphics
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.sunos => Sun makefile
makefile.solaris => Solaris 2.X makefile
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.so9 => Solaris 9 makefile
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.32sunu => Sun Ultra 32-bit makefile
makefile.64sunu => Sun Ultra 64-bit makefile
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index 32b6a52d3..c3d015aae 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
#! /bin/sh
# Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.4.12beta01.
+# Generated by GNU Autoconf 2.65 for libpng 1.4.12.
#
# Report bugs to <png-mng-implement@lists.sourceforge.net>.
#
@@ -562,8 +562,8 @@ MAKEFLAGS=
# Identity of this package.
PACKAGE_NAME='libpng'
PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.4.12beta01'
-PACKAGE_STRING='libpng 1.4.12beta01'
+PACKAGE_VERSION='1.4.12'
+PACKAGE_STRING='libpng 1.4.12'
PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
PACKAGE_URL=''
@@ -1292,7 +1292,7 @@ if test "$ac_init_help" = "long"; then
# Omit some internal or obsolete options to make the list less imposing.
# This message is too long to be a string in the A/UX 3.1 sh.
cat <<_ACEOF
-\`configure' configures libpng 1.4.12beta01 to adapt to many kinds of systems.
+\`configure' configures libpng 1.4.12 to adapt to many kinds of systems.
Usage: $0 [OPTION]... [VAR=VALUE]...
@@ -1362,7 +1362,7 @@ fi
if test -n "$ac_init_help"; then
case $ac_init_help in
- short | recursive ) echo "Configuration of libpng 1.4.12beta01:";;
+ short | recursive ) echo "Configuration of libpng 1.4.12:";;
esac
cat <<\_ACEOF
@@ -1467,7 +1467,7 @@ fi
test -n "$ac_init_help" && exit $ac_status
if $ac_init_version; then
cat <<\_ACEOF
-libpng configure 1.4.12beta01
+libpng configure 1.4.12
generated by GNU Autoconf 2.65
Copyright (C) 2009 Free Software Foundation, Inc.
@@ -1892,7 +1892,7 @@ cat >config.log <<_ACEOF
This file contains any messages produced by compilers while
running configure, to aid debugging if configure makes a mistake.
-It was created by libpng $as_me 1.4.12beta01, which was
+It was created by libpng $as_me 1.4.12, which was
generated by GNU Autoconf 2.65. Invocation command line was
$ $0 $@
@@ -2700,7 +2700,7 @@ fi
# Define the identity of the package.
PACKAGE='libpng'
- VERSION='1.4.12beta01'
+ VERSION='1.4.12'
cat >>confdefs.h <<_ACEOF
@@ -2764,7 +2764,7 @@ fi
-PNGLIB_VERSION=1.4.12beta01
+PNGLIB_VERSION=1.4.12
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=12
@@ -12175,7 +12175,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
# report actual input values of CONFIG_FILES etc. instead of their
# values after options handling.
ac_log="
-This file was extended by libpng $as_me 1.4.12beta01, which was
+This file was extended by libpng $as_me 1.4.12, which was
generated by GNU Autoconf 2.65. Invocation command line was
CONFIG_FILES = $CONFIG_FILES
@@ -12241,7 +12241,7 @@ _ACEOF
cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
ac_cs_version="\\
-libpng config.status 1.4.12beta01
+libpng config.status 1.4.12
configured by $0, generated by GNU Autoconf 2.65,
with options \\"\$ac_cs_config\\"
diff --git a/configure.ac b/configure.ac
index 188ef4116..57a450ee2 100644
--- a/configure.ac
+++ b/configure.ac
@@ -16,14 +16,14 @@ dnl should not be necessary to regenerate configure if the time
dnl stamps are correct
AC_PREREQ(2.59)
-AC_INIT([libpng], [1.4.12beta01], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.4.12], [png-mng-implement@lists.sourceforge.net])
AM_INIT_AUTOMAKE
dnl stop configure from automagically running automake
AM_MAINTAINER_MODE
dnl Version number stuff here:
-PNGLIB_VERSION=1.4.12beta01
+PNGLIB_VERSION=1.4.12
PNGLIB_MAJOR=1
PNGLIB_MINOR=4
PNGLIB_RELEASE=12
diff --git a/contrib/pngsuite/README b/contrib/pngsuite/README
index 714baff2b..ec4af9473 100644
--- a/contrib/pngsuite/README
+++ b/contrib/pngsuite/README
@@ -1,14 +1,15 @@
pngsuite
--------
-(c) Willem van Schaik, 1999, 2011
+(c) Willem van Schaik, 1999, 2011, 2012
+Two images are by Glenn Randers-Pehrson, 2012
Permission to use, copy, modify, and distribute these images for any
purpose and without fee is hereby granted.
-The 15 "bas*.png" images are part of the much larger PngSuite test-set of
-images, available for developers of PNG supporting software. The
-complete set, available at http:/www.schaik.com/pngsuite/, contains
+The 15 "bas*.png" images are part of the much larger PngSuite test-set of
+images, available for developers of PNG supporting software. The
+complete set, available at http:/www.schaik.com/pngsuite/, contains
a variety of images to test interlacing, gamma settings, ancillary
chunks, etc.
@@ -38,6 +39,8 @@ can use them to test the proper functioning of PNG software.
basn6a08.png 8-bit RGBA
basn6a16.png 16-bit RGBA
+ ftbbn0g01.png 1-bit grayscale, black bKGD
+ ftbbn0g02.png 2-bit grayscale, black bKGD
ftbbn0g04.png 4-bit grayscale, black bKGD
ftbbn2c16.png 16-bit truecolor, black bKGD
ftbbn3p08.png 8-bit paletted, black bKGD
@@ -48,7 +51,7 @@ can use them to test the proper functioning of PNG software.
ftbwn3p08.png 8-bit paletted, white bKGD
ftbyn3p08.png 8-bit paletted, yellow bKGD
ftp0n0g08.png 8-bit grayscale, opaque
- ftp0n2c08.png 8-bit truecolor, opaque
+ ftp0n2c08.png 8-bit truecolor, opaque
ftp0n3p08.png 8-bit paletted, opaque
ftp1n3p08.png 8-bit paletted, no bKGD
diff --git a/contrib/pngsuite/ftbbn0g01.png b/contrib/pngsuite/ftbbn0g01.png
new file mode 100644
index 000000000..ba746ffb2
--- /dev/null
+++ b/contrib/pngsuite/ftbbn0g01.png
Binary files differ
diff --git a/contrib/pngsuite/ftbbn0g02.png b/contrib/pngsuite/ftbbn0g02.png
new file mode 100644
index 000000000..3d83bd690
--- /dev/null
+++ b/contrib/pngsuite/ftbbn0g02.png
Binary files differ
diff --git a/contrib/pngsuite/ftbbn1g04.png b/contrib/pngsuite/ftbbn0g04.png
index 39a7050d2..39a7050d2 100644
--- a/contrib/pngsuite/ftbbn1g04.png
+++ b/contrib/pngsuite/ftbbn0g04.png
Binary files differ
diff --git a/contrib/pngsuite/ftbwn1g16.png b/contrib/pngsuite/ftbwn0g16.png
index 99bdeed2b..99bdeed2b 100644
--- a/contrib/pngsuite/ftbwn1g16.png
+++ b/contrib/pngsuite/ftbwn0g16.png
Binary files differ
diff --git a/contrib/pngsuite/ftp0n1g08.png b/contrib/pngsuite/ftp0n0g08.png
index 333465fcd..333465fcd 100644
--- a/contrib/pngsuite/ftp0n1g08.png
+++ b/contrib/pngsuite/ftp0n0g08.png
Binary files differ
diff --git a/libpng-1.4.12beta01.txt b/libpng-1.4.12.txt
index 85be8ff2e..783ee8a0f 100644
--- a/libpng-1.4.12beta01.txt
+++ b/libpng-1.4.12.txt
@@ -1,6 +1,6 @@
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.12beta01 - April 26, 2012
+ libpng version 1.4.12 - July 10, 2012
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.12beta01 - April 26, 2012
+ libpng versions 0.97, January 1998, through 1.4.12 - July 10, 2012
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -906,7 +906,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.12beta01, not all possible expansions are supported.
+As of libpng version 1.4.12, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -3312,13 +3312,13 @@ Other rules can be inferred by inspecting the libpng source.
XIII. Y2K Compliance in libpng
-April 26, 2012
+July 10, 2012
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.12beta01 are Y2K compliant. It is my belief that earlier
+upward through 1.4.12 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 1e5622432..2999adca4 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "April 26, 2012"
+.TH LIBPNG 3 "July 10, 2012"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.12beta01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.12
.SH SYNOPSIS
\fI\fB
@@ -895,7 +895,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng.txt - A description on how to use and modify libpng
- libpng version 1.4.12beta01 - April 26, 2012
+ libpng version 1.4.12 - July 10, 2012
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -906,7 +906,7 @@ libpng.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.4.12beta01 - April 26, 2012
+ libpng versions 0.97, January 1998, through 1.4.12 - July 10, 2012
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2010 Glenn Randers-Pehrson
@@ -1801,7 +1801,7 @@ things.
As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
added. It expands the sample depth without changing tRNS to alpha.
-As of libpng version 1.4.12beta01, not all possible expansions are supported.
+As of libpng version 1.4.12, not all possible expansions are supported.
In the following table, the 01 means grayscale with depth<8, 31 means
indexed with depth<8, other numerals represent the color type, "T" means
@@ -4207,13 +4207,13 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIII. Y2K Compliance in libpng
-April 26, 2012
+July 10, 2012
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.4.12beta01 are Y2K compliant. It is my belief that earlier
+upward through 1.4.12 are Y2K compliant. It is my belief that earlier
versions were also Y2K compliant.
Libpng only has three year fields. One is a 2-byte unsigned integer that
@@ -4421,7 +4421,7 @@ the first widely used release:
1.4.10 14 10410 14.so.14.10[.0]
1.4.11rc01 14 10411 14.so.14.11[.0]
1.4.11 14 10411 14.so.14.11[.0]
- 1.4.12beta01 14 10412 14.so.14.12[.0]
+ 1.4.12 14 10412 14.so.14.12[.0]
Henceforth the source version will match the shared-library minor
and patch numbers; the shared-library major version number will be
@@ -4477,7 +4477,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.4.12beta01 - April 26, 2012:
+Libpng version 1.4.12 - July 10, 2012:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -4500,7 +4500,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.4.12beta01, April 26, 2012, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.12, July 10, 2012, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -4599,7 +4599,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 26, 2012
+July 10, 2012
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index a33fbf338..4acd29403 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "April 26, 2012"
+.TH LIBPNGPF 3 "July 10, 2012"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.4.12beta01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.4.12
(private functions)
.SH SYNOPSIS
\fB#include <png.h>\fP
diff --git a/png.5 b/png.5
index ce98b56c0..a597ddc1b 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "April 26, 2012"
+.TH PNG 5 "July 10, 2012"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index b65e5dfdc..f44e20efa 100644
--- a/png.c
+++ b/png.c
@@ -17,7 +17,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_12beta01 Your_png_h_is_not_version_1_4_12beta01;
+typedef version_1_4_12 Your_png_h_is_not_version_1_4_12;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -547,13 +547,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.4.12beta01 - April 26, 2012" PNG_STRING_NEWLINE \
+ "libpng version 1.4.12 - July 10, 2012" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.12beta01 - April 26, 2012\
+ return ((png_charp) "libpng version 1.4.12 - July 10, 2012\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index b8b5c6191..6d1378f5f 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.4.12beta01 - April 26, 2012
+ * libpng version 1.4.12 - July 10, 2012
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index f74e50922..b833f60ea 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
/* pngpriv.h - private declarations for use inside libpng
*
- * libpng version 1.4.12beta01 - April 26, 2012
+ * libpng version 1.4.12 - July 10, 2012
* For conditions of distribution and use, see copyright notice in png.h
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 1bd865ca1..070f493e6 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1702,4 +1702,4 @@ main(int argc, char *argv[])
}
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_4_12beta01 your_png_h_is_not_version_1_4_12beta01;
+typedef version_1_4_12 your_png_h_is_not_version_1_4_12;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 53659feff..a924037a0 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.4.12beta01 - April 26, 2012
+libpng version 1.4.12 - July 10, 2012
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 3079bfef2..24b07d920 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source and build
*
- * libpng version 1.4.12beta01 - April 26, 2012
+ * libpng version 1.4.12 - July 10, 2012
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 7c3bcc5eb..63d71cc48 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
-Makefiles for libpng version 1.4.12beta01 - April 26, 2012
+Makefiles for libpng version 1.4.12 - July 10, 2012
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@ Makefiles for libpng version 1.4.12beta01 - April 26, 2012
makefile.dec => DEC Alpha UNIX makefile
makefile.dj2 => DJGPP 2 makefile
makefile.elf => Linux/ELF makefile symbol versioning,
- (gcc, creates libpng14.so.14.1.4.12beta01)
+ (gcc, creates libpng14.so.14.1.4.12)
makefile.freebsd => FreeBSD makefile
makefile.gcc => Generic gcc makefile
makefile.hpgcc => HPUX makefile using gcc
@@ -36,12 +36,12 @@ Makefiles for libpng version 1.4.12beta01 - April 26, 2012
makefile.os2 => OS/2 Makefile (gcc and emx, requires pngos2.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng14.so.14.1.4.12beta01)
+ creates libpng14.so.14.1.4.12)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng14.so.14.1.4.12beta01)
+ creates libpng14.so.14.1.4.12)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng14.so.14.1.4.12beta01)
+ creates libpng14.so.14.1.4.12)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 11c48a8af..4b8bc1bc6 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.4.12beta01
+version=1.4.12
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index c8bcc9d50..0e258e1c3 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng14
Name: libpng
Description: Loads and saves PNG files
-Version: 1.4.12beta01
+Version: 1.4.12
Libs: -L${libdir} -lpng14
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index afe8175c2..31dde6c3d 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng14
LIB= png14
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.12beta01
+SHLIB_MINOR= 1.4.12
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index bea0412f8..dd091a214 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 3
-SHLIB_MINOR= 1.4.12beta01
+SHLIB_MINOR= 1.4.12
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 63a1728e3..91519cb5e 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.4.12beta01
+SHLIB_MINOR= 1.4.12
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index 852a883c8..5f610726b 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@ LIBRARY lpngce
png_get_int_32
EXPORTS
-;Version 1.4.12beta01
+;Version 1.4.12
png_build_grayscale_palette @1
; png_check_sig @2
png_chunk_error @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index 9399d575d..b2978c594 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
; PNG.LIB module definition file for OS/2
;----------------------------------------
-; Version 1.4.12beta01
+; Version 1.4.12
LIBRARY PNG
DESCRIPTION "PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index c519e37bb..fcf0c5653 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
LIBRARY
EXPORTS
-;Version 1.4.12beta01
+;Version 1.4.12
png_build_grayscale_palette
png_chunk_error
png_chunk_warning
diff --git a/png.h b/png.h
index d7904724d..9eada7d43 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.4.12beta01 - April 26, 2012
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.4.12beta01 - April 26, 2012: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -169,7 +169,7 @@
* 1.4.10 14 10410 14.so.14.10[.0]
* 1.4.11rc01 14 10411 14.so.14.11[.0]
* 1.4.11 14 10411 14.so.14.11[.0]
- * 1.4.12beta01 14 10412 14.so.14.12[.0]
+ * 1.4.12 14 10412 14.so.14.12[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -201,7 +201,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.4.12beta01, April 26, 2012, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -313,13 +313,13 @@
* Y2K compliance in libpng:
* =========================
*
- * April 26, 2012
+ * July 10, 2012
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.4.12beta01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.4.12 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -375,9 +375,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.12beta01"
+#define PNG_LIBPNG_VER_STRING "1.4.12"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.4.12beta01 - April 26, 2012\n"
+ " libpng version 1.4.12 - July 10, 2012\n"
#define PNG_LIBPNG_VER_SONUM 14
#define PNG_LIBPNG_VER_DLLNUM 14
@@ -390,7 +390,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 0
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -407,7 +407,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -1501,7 +1501,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_4_12beta01;
+typedef png_structp version_1_4_12;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.4.12beta01 - April 26, 2012
+ * libpng version 1.4.12 - July 10, 2012
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.4.12beta01 - April 26, 2012: Glenn
+ * libpng versions 0.97, January 1998, through 1.4.12 - July 10, 2012: Glenn
* See also "Contributing Authors", below.
*
@@ -201,7 +201,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.4.12beta01, April 26, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.12, July 10, 2012, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5